ddd dd bold yy

  77777

  1. arabic (decimal) numbering

  2. loweralpha numbering ss

  3. lowerroman numbering

  4. upperalpha numbering

  5. upperroman numbering

## Text formatting

    *bold text*                 (boldface font)
    _emphasized text_           (normally italics)
    'emphasized text'
    +monospaced text+           (proportional font)
    `monospaced text`           (inline literal passthrough)

## Document links

    [[id]]                      (define link target)
    <<id,caption>>              (link to target id)
    link:filename#id[caption]   (link to external HTML file)

## URLs

    Use normal URL and email addess syntax or:

    http:address[caption]       (link to web page)
    mailto:address[caption]     (link to mail recipient)

## Images

    image:filename[caption]     (inline image)
    image::filename[caption]    (block image)

## Document header

    The Document Title
    ==================
    author <email>
    revision, date

author, email, revision and date are optional.

## Section title underlines

    Underlined:

    Level 0                     (document title)
    =======
    Level 1
    -------
    Level 2
    ~~~~~~~
    Level 3
    ^^^^^^^
    Level 4                     (bottom level)
    +++++++

    Single line:

    = Level 0 =                 (document title)
    == Level 1 ==
    === Level 2 ===
    ==== Level 3 ====
    ===== Level 4 =====         (bottom level)

## Paragraphs

A normal paragraph. (styles: literal,verse,quote,listing, NOTE,TIP,WARNING,IMPORTANT,CAUTION) An indented literal paragraph.

## Delimited blocks

Delimiters must begin at left margin.

    -------------------         (styles: source,music,graphviz)
    listing block
    -------------------

    ...................         (styles: listing,verse)
    literal block
    ...................

    *******************
    sidebar block
    *******************

    [style, author, cite]
    ___________________         (styles: quote,verse)
    quote block
    ___________________

    ===================         (styles: NOTE,TIP,WARNING,
    example block                        IMPORTANT,CAUTION)
    ===================

    ///////////////////
    comment block
    ///////////////////

    +++++++++++++++++++         (styles: pass,asciimath,latexmath)
    passthrough block
    +++++++++++++++++++

    [style]                     (styles: abstract,partintro)
    --
    open block
    --

## More block elements

    [attributes list]
    .Block title
    // Comment line
    include::filename[]

## Tables

    .An example table
    [width="40%",cols="^,2m",frame="topbot",options="header,footer"]
    |======================
    |Column 1 |Column 2
    |1        |Item 1
    |2        |Item 2
    |3        |Item 3
    |6        |Three items
    |======================

    Common attributes:

    grid:    none,cols,rows,all
    frame:   topbot,none,sides,all
    options: header,footer
    format:  psv,csv,dsv
    valign:  top,bottom,middle
    width:   1%..100%
    cols:    colspec[,colspec,...]

    colspec:    [multiplier*][align][width][style]
    multiplier: 1...
    width:      1... or 1%...100%
    align:      [horiz][.vert]
                 horiz: < (left), ^ (center), > (right)
                 vert:  < (top),  ^ (middle), > (bottom)
    style:      d[efault], e[mphasis], m[onospaced], a[sciidoc],
                s[trong], l[iteral], v[erse], h[eader]
    cell:       [cellspec]|data
    cellspec:   [span*|+][align][style]
    span:       [colspan][.rowspan]
                 colspan: 1...
                 rowspan: 1...

## Bulleted lists

- item text

  - item text

    - item text

      - item text

        - item text

          - item text

                (styles: callout,bibliography)

## Numbered lists

1. arabic (decimal) numbering

   1. loweralpha numbering

      1. upperalpha numbering

         1. lowerroman numbering

            1. upperroman numbering

               1. arabic (decimal) numbering

                  1. loweralpha numbering

                     1. lowerroman numbering

                        1. upperalpha numbering

                           1. upperroman numbering

                                  (styles: arabic,loweralpha,upperalpha,lowerroman,upperroman)

## Labeled lists

label

  item text

  label

    item text

    label

      item text

      label

        item text

            (styles: horizontal,vertical,glossary,qanda,bibliograpy)

## More inline elements

    footnote:[footnote text]    (document footnote)

F:\Python27\asciidoc-8.6.8>

MS-DOS directory listing

     10/17/97   9:04         <DIR>    bin
     10/16/97  14:11         <DIR>    DOS            <1>
     10/16/97  14:40         <DIR>    Program Files
     10/16/97  14:46         <DIR>    TEMP
     10/17/97   9:04         <DIR>    tmp
     10/16/97  14:37         <DIR>    WINNT
     10/16/97  14:25             119  AUTOEXEC.BAT   <2>
      2/13/94   6:21          54,619  COMMAND.COM    <2>
     10/16/97  14:25             115  CONFIG.SYS     <2>
     11/16/97  17:17      61,865,984  pagefile.sys
      2/13/94   6:21           9,349  WINA20.386     <3>

1. This directory holds MS-DOS.

2. System startup code for DOS.

3. Some sort of Windows 3.1 hack.

   1. List item one.

      List item one continued with a second paragraph followed by an Indented block.

          $ ls *.sh
          $ mv *.sh ~/tmp

      List item continued with a third paragraph.

   2. List item two continued with an open block.

      This paragraph is part of the preceding list item.

      1. This list is nested and does not require explicit item continuation.

         This paragraph is part of the preceding list item.

      2. List item b.

      This paragraph belongs to item two of the outer list.

# Asciidoc syntax test document

- Praesent eget purus quis magna eleifend eleifend.

  1. Fusce euismod commodo velit.

     1. Fusce euismod commodo velit.

     2. Vivamus fringilla mi eu lacus.

     3. Donec eget arcu bibendum nunc consequat lobortis.

  2. Vivamus fringilla mi eu lacus.

     1. Fusce euismod commodo velit.

     2. Vivamus fringilla mi eu lacus.

  3. Donec eget arcu bibendum nunc consequat lobortis.

  4. Nam fermentum mattis ante.

- Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

  - Fusce euismod commodo velit.

    - Qui in magna commodo, est labitur dolorum an. Est ne magna primis adolescens. Sit munere ponderum dignissim et. Minim luptatum et vel.

    - Vivamus fringilla mi eu lacus.

  - Donec eget arcu bibendum nunc consequat lobortis.

- Nulla porttitor vulputate libero.

  1. Fusce euismod commodo velit.

  2. Vivamus fringilla mi eu lacus.

     1. Fusce euismod commodo velit. …… Vivamus fringilla mi eu lacus.

  3. Donec eget arcu bibendum nunc consequat loborti

## Emphasizing and quoting

Emphasized, bold etc. text preceded or followed by dashes is handled correctly

- bold- , --bold, bold—blanonbold.

- emph, --emph, emph--bla_nonemph_.

- emph, --emph, emph--bla_nonemph_.

- `mono`, --`mono`, `mono`--bla+nonmono+.

- `mono`, --`mono`, `mono`--bla`nonmono`.

- “quot”, --“quot”, “quot”--bla`‘nonquot’'.

Emphasizing a complete multi-line paragraph should be possible too ! And So it will be…

## Lists

Correct indentation simple numbers at the start of lines should not be confused with list items. These are numbered lists, so lines following a list item should be indented

1. Integer numbered list item. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

   1. Integer numbered list item with optional numbering. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

   2. Integer numbered list item with optional numbering. Lorem ipsum dolor sit amet, consectetuer adipiscing elit.

      1. lower roman numbering

         1. upperroman numbering

2. loweralpha numbering

   1. upperalpha numbering

But these are just numbers that happen to occur at the start of a line and should not trigger indentation

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Fusce euismod od 1 commodo velit. Qui in magna commodo, est labitur dolorum an. Est ne magna primis. Sit munere ponderum dignissim et. Minim luptatum et vel. Vivamus 12.5. mi eu lacus. Donec eget arcu bibendum nunc consequat lobortis. Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Fusce euismod commodo

Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Fusce euismod od c. commodo velit. Qui in magna commodo, est labitur dolorum an. Est ne magna primis. Sit munere ponderum dignissim et. Minim luptatum et vel. (Vivamus xi) mi eu lacus. Donec eget arcu bibendum nunc consequat lobortis. Lorem ipsum dolor sit amet, consectetuer adipiscing elit. Fusce euismod commodo

     Comments are taken care off as well
    == Blocks
    Many ways to make $$blocks$$

And even comment blocks do well

## Admonitions

Warning | Admonitions have a special meaning too.

Note | Also when used in block mode.

## Definitions

Definition 1 This is it Definition 2 This is it too

## Inserting quotes

Typing inserts a pair of quotes (‘`’') and places the cursor between them. Works in both insert and command mode (switching to insert mode). Typing a single works as usual (though with a slight delay).

## URLs and email addresses

So when using a URL like httpdag.wieers.com[Test] it needs to stand out, same is true for email addresses like dag@wieers.com

    vim set syntax=asciidoc